@@ -1,14 +1,15 @@
 package Workflow::Action::Mailer;
 
-# $Id: Mailer.pm 330 2007-08-12 11:01:58Z jonasbn $
+# $Id: Mailer.pm 539 2012-10-25 16:19:14Z jonasbn $
 
+use warnings;
 use strict;
 use base qw( Workflow::Action );
 
-$Workflow::Action::Mailer::VERSION  = '1.01';
+$Workflow::Action::Mailer::VERSION = '1.01';
 
 sub execute {
-    my ( $self ) = @_;
+    my ($self) = @_;
     return 1;
 }
 
@@ -20,6 +21,10 @@ __END__
 
 Workflow::Action::Mailer - a stub for a SMTP capable action
 
+=head1 VERSION
+
+This documentation describes version 1.01 of this package
+
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
@@ -55,4 +60,4 @@ Jonas B. Nielsen (jonasbn) E<lt>jonasbn@cpan.orgE<gt> is the current maintainer.
 
 Chris Winters E<lt>chris@cwinters.comE<gt>, original author.
 
-=cut
\ No newline at end of file
+=cut
