@@ -1,27 +1,29 @@
 package Workflow::Condition;
 
-# $Id: Condition.pm 317 2007-07-05 05:46:25Z jonasbn $
+# $Id: Condition.pm 539 2012-10-25 16:19:14Z jonasbn $
 
+use warnings;
 use strict;
 use base qw( Workflow::Base );
+use Carp qw(croak);
 
 $Workflow::Condition::VERSION = '1.07';
 
 my @FIELDS = qw( name class );
-__PACKAGE__->mk_accessors( @FIELDS );
+__PACKAGE__->mk_accessors(@FIELDS);
 
 sub init {
     my ( $self, $params ) = @_;
     $self->name( $params->{name} );
     $self->class( $params->{class} );
-    $self->_init( $params );
+    $self->_init($params);
 }
 
-sub _init { return }
+sub _init {return}
 
 sub evaluate {
-    my ( $self ) = @_;
-    die "Class ", ref( $self ), " must implement 'evaluate()'!\n";
+    my ($self) = @_;
+    croak "Class ", ref($self), " must implement 'evaluate()'!\n";
 }
 
 1;
@@ -32,6 +34,10 @@ __END__
 
 Workflow::Condition - Evaluate a condition depending on the workflow state and environment
 
+=head1 VERSION
+
+This documentation describes version 1.07 of this package
+
 =head1 SYNOPSIS
 
  # First declare the condition in a 'workflow_condition.xml'...
@@ -113,6 +119,30 @@ action specification in a seperate file then nothing will happen. The
 reference to the condition must be defined inside of the state/workflow
 specification.
 
+=head1 CONFIGURATION
+
+While some conditions apply to all workflows, you may have a case where
+a condition has different implementations for different workflow types.
+For example, IsAdminUser may look in two different places for two
+different workflow types, but you want to use the same condition name
+for both.
+
+You can accomplish this by adding a type in the condition configuration.
+
+ <conditions>
+ <type>Ticket</type>
+   <condition
+      name="IsAdminUser"
+      class="MyApp::Condition::IsAdminUser">
+         <param name="admin_group_id" value="5" />
+         <param name="admin_group_id" value="6" />
+   </condition>
+ ...
+
+The type must match a loaded workflow type, or the condition won't work.
+When the workflow looks for a condition, it will look for a typed condition
+first. If it doesn't find one, it will look for non-typed conditions.
+
 =head1 SUBCLASSING
 
 =head2 Strategy
