@@ -1,10 +1,11 @@
 package Workflow::Condition::HasUser;
 
-# $Id: HasUser.pm 285 2007-06-18 19:57:58Z jonasbn $
+# $Id: HasUser.pm 539 2012-10-25 16:19:14Z jonasbn $
 
+use warnings;
 use strict;
 use base qw( Workflow::Condition );
-use Log::Log4perl       qw( get_logger );
+use Log::Log4perl qw( get_logger );
 use Workflow::Exception qw( condition_error );
 
 $Workflow::Condition::HasUser::VERSION = '1.05';
@@ -20,12 +21,13 @@ sub _init {
 sub evaluate {
     my ( $self, $wf ) = @_;
     my $log = get_logger();
-    $log->is_debug && $log->debug( "Trying to execute condition ", ref( $self ) );
-    my $user_key = $self->param( 'user_key' );
-    my $current_user = $wf->context->param( $user_key );
+    $log->is_debug
+        && $log->debug( "Trying to execute condition ", ref $self );
+    my $user_key     = $self->param('user_key');
+    my $current_user = $wf->context->param($user_key);
     $log->debug( "Current user in the context is '$current_user' retrieved ",
-                 "using parameter key '$user_key'" );
-    unless ( $current_user ) {
+        "using parameter key '$user_key'" );
+    unless ($current_user) {
         condition_error
             "No current user available in workflow context key '$user_key'";
     }
@@ -39,6 +41,10 @@ __END__
 
 Workflow::Condition::HasUser - Condition to determine if a user is available
 
+=head1 VERSION
+
+This documentation describes version 1.05 of this package
+
 =head1 SYNOPSIS
 
  # First setup the condition
@@ -86,7 +92,13 @@ Key in workflow context to check for data. If not specified we use
 
 =head2 METHODS
 
-#=head3 evaluate
+=head3 evaluate ( $wf )
+
+Method to evaluate whether a user has been set for a workflow.
+
+Takes a workflow object as parameter
+
+Throws L<Workflow::Exception> if evaluation fails
 
 =head1 SEE ALSO
 
