@@ -1,54 +1,68 @@
 package Workflow::Config::Perl;
 
-# $Id: Perl.pm 292 2007-06-19 14:48:02Z jonasbn $
+# $Id: Perl.pm 539 2012-10-25 16:19:14Z jonasbn $
 
+use warnings;
 use strict;
-use base                qw( Workflow::Config );
-use Log::Log4perl       qw( get_logger );
+use base qw( Workflow::Config );
+use Log::Log4perl qw( get_logger );
 use Workflow::Exception qw( configuration_error );
-use Data::Dumper        qw( Dumper );
+use Data::Dumper qw( Dumper );
+use English qw( -no_match_vars );
 
 $Workflow::Config::Perl::VERSION = '1.03';
 
-my ( $log );
-
 sub parse {
     my ( $self, $type, @items ) = @_;
-    $log ||= get_logger();
+    my $log ||= get_logger();
 
-    $self->_check_config_type( $type );
+    $self->_check_config_type($type);
 
-    if (! scalar @items) {
+    if ( !scalar @items ) {
         return @items;
     }
 
-    my @config_items = Workflow::Config::_expand_refs( @items );
+    my @config_items = Workflow::Config::_expand_refs(@items);
     return () unless ( scalar @config_items );
 
     my @config = ();
-    foreach my $item ( @config_items ) {
+    foreach my $item (@config_items) {
         my ( $file_name, $method );
         if ( ref $item ) {
-            $method = '_translate_perl';
+            $method    = '_translate_perl';
             $file_name = '[scalar ref]';
         }
 
         # $item is a filename...
         else {
-            $method = '_translate_perl_file';
+            $method    = '_translate_perl_file';
             $file_name = $item;
         }
-        $log->is_info &&
-            $log->info( "Will parse '$type' Perl config file '$file_name'" );
+        $log->is_info
+            && $log->info("Will parse '$type' Perl config file '$file_name'");
         my $this_config = $self->$method( $type, $item );
-        $log->is_info &&
-            $log->info( "Parsed Perl '$file_name' ok" );
-        if ( ref $this_config->{ $type } eq 'ARRAY' ) {
-            $log->debug( "Adding multiple configurations for '$type'" );
-            push @config, @{ $this_config->{ $type } };
-        }
-        else {
-            $log->debug( "Adding single configuration for '$type'" );
+
+        #warn "This config looks like:";
+        #warn Dumper (\$this_config);
+        $log->is_info
+            && $log->info("Parsed Perl '$file_name' ok");
+
+        if ( exists $this_config->{'type'} ) {
+            $log->debug("Adding typed configuration for '$type'");
+            push @config, $this_config;
+        } elsif ( $type eq 'persister'
+            and ref $this_config->{$type} eq 'ARRAY' )
+        {
+
+            # This special exception for persister is required because
+            # the config design for persisters was different from the
+            # other config types. It didn't have a top level 'persister'
+            # element. For backward compatibility, I'm adding this
+            # exception here.
+            $log->debug("Adding multiple configurations for '$type'");
+            push @config, @{ $this_config->{$type} };
+        } else {
+            $log->debug("Adding single configuration for '$type'");
             push @config, $this_config;
         }
     }
@@ -59,14 +73,14 @@ sub _translate_perl_file {
     my ( $class, $type, $file ) = @_;
     my $log = get_logger();
 
-    local $/ = undef;
+    local $INPUT_RECORD_SEPARATOR = undef;
     open( CONF, '<', $file )
         || configuration_error "Cannot read file '$file': $!";
     my $config = <CONF>;
-    close( CONF );
+    close(CONF) || configuration_error "Cannot close file '$file': $!";
     my $data = $class->_translate_perl( $type, $config, $file );
-    $log->is_debug &&
-        $log->debug( "Translated '$type' '$file' into: ", Dumper( $data ) );
+    $log->is_debug
+        && $log->debug( "Translated '$type' '$file' into: ", Dumper($data) );
     return $data;
 }
 
@@ -76,15 +90,13 @@ sub _translate_perl {
 
     no strict 'vars';
     my $data = eval $config;
-    if ( $@ ) {
+    if ($EVAL_ERROR) {
         configuration_error "Cannot evaluate perl data structure ",
-                            "in '$file': $@";
+            "in '$file': $EVAL_ERROR";
     }
     return $data;
 }
 
-
-
 1;
 
 __END__
@@ -93,6 +105,10 @@ __END__
 
 Workflow::Config::Perl - Parse workflow configurations as Perl data structures
 
+=head1 VERSION
+
+This documentation describes version 1.03 of this package
+
 =head1 SYNOPSIS
 
  # either of these is acceptable
