@@ -1,27 +1,31 @@
 package Workflow::Config::XML;
 
-# $Id: XML.pm 316 2007-07-04 19:17:50Z jonasbn $
+# $Id: XML.pm 539 2012-10-25 16:19:14Z jonasbn $
 
+use warnings;
 use strict;
 use base qw( Workflow::Config );
-use Log::Log4perl       qw( get_logger );
+use Log::Log4perl qw( get_logger );
 use Workflow::Exception qw( configuration_error );
+use Carp qw(croak);
+use English qw( -no_match_vars );
 
 $Workflow::Config::XML::VERSION = '1.05';
 
-my ( $log );
+my ($log);
 
 my %XML_OPTIONS = (
     action => {
-        ForceArray => [ 'action', 'field', 'source_list', 'param', 'validator', 'arg' ],
-        KeyAttr    => [],
+        ForceArray =>
+            [ 'action', 'field', 'source_list', 'param', 'validator', 'arg' ],
+        KeyAttr => [],
     },
     condition => {
         ForceArray => [ 'condition', 'param' ],
         KeyAttr    => [],
     },
     persister => {
-        ForceArray => [ 'persister' ],
+        ForceArray => ['persister'],
         KeyAttr    => [],
     },
     validator => {
@@ -29,8 +33,12 @@ my %XML_OPTIONS = (
         KeyAttr    => [],
     },
     workflow => {
-        ForceArray => [ 'extra_data', 'state', 'action',  'resulting_state', 'condition', 'observer' ],
-        KeyAttr    => [],
+        ForceArray => [
+            'extra_data', 'state',
+            'action',     'resulting_state',
+            'condition',  'observer'
+        ],
+        KeyAttr => [],
     },
 );
 
@@ -40,32 +48,34 @@ sub parse {
     my ( $self, $type, @items ) = @_;
     $log ||= get_logger();
 
-    $self->_check_config_type( $type );
-    my @config_items = Workflow::Config::_expand_refs( @items );
+    $self->_check_config_type($type);
+    my @config_items = Workflow::Config::_expand_refs(@items);
     return () unless ( scalar @config_items );
 
     my @config = ();
-    foreach my $item ( @config_items ) {
+    foreach my $item (@config_items) {
         my $file_name = ( ref $item ) ? '[scalar ref]' : $item;
-        $log->is_info &&
-            $log->info( "Will parse '$type' XML config file '$file_name'" );
+        $log->is_info
+            && $log->info("Will parse '$type' XML config file '$file_name'");
         my $this_config;
-        eval{
-            $this_config = $self->_translate_xml( $type, $item );
-        };
+        eval { $this_config = $self->_translate_xml( $type, $item ); };
+
         # If processing multiple config files, this makes it much easier
         # to find a problem.
-        die "Processing $file_name: $@" if $@;
-        $log->is_info &&
-            $log->info( "Parsed XML '$file_name' ok" );
-        if ( ref $this_config->{ $type } eq 'ARRAY' ) {
-            $log->is_debug &&
-                $log->debug( "Adding multiple configurations for '$type'" );
-            push @config, @{ $this_config->{ $type } };
-        }
-        else {
-            $log->is_debug &&
-                $log->debug( "Adding single configuration for '$type'" );
+        croak "Processing $file_name: $EVAL_ERROR" if $EVAL_ERROR;
+        $log->is_info
+            && $log->info("Parsed XML '$file_name' ok");
+
+        # This sets the outer-most tag to use
+        # when returning the parsed XML.
+        my $outer_tag = $self->get_config_type_tag($type);
+        if ( ref $this_config->{$outer_tag} eq 'ARRAY' ) {
+            $log->is_debug
+                && $log->debug("Adding multiple configurations for '$type'");
+            push @config, @{ $this_config->{$outer_tag} };
+        } else {
+            $log->is_debug
+                && $log->debug("Adding single configuration for '$type'");
             push @config, $this_config;
         }
     }
@@ -75,20 +85,19 @@ sub parse {
 # $config can either be a filename or scalar ref with file contents
 
 sub _translate_xml {
-    my( $self, $type, $config ) = @_;
-    unless ( $XML_REQUIRED ) {
+    my ( $self, $type, $config ) = @_;
+    unless ($XML_REQUIRED) {
         eval { require XML::Simple };
-        if ( $@ ) {
+        if ($EVAL_ERROR) {
             configuration_error "XML::Simple must be installed to parse ",
-                                "configuration files/data in XML format";
-        }
-        else {
-            XML::Simple->import( ':strict' );
+                "configuration files/data in XML format";
+        } else {
+            XML::Simple->import(':strict');
             $XML_REQUIRED++;
         }
-    };
-    my $options = $XML_OPTIONS{ $type } || {};
-    my $data = XMLin( $config, %{ $options } );
+    }
+    my $options = $XML_OPTIONS{$type} || {};
+    my $data = XMLin( $config, %{$options} );
     return $data;
 }
 
@@ -100,6 +109,10 @@ __END__
 
 Workflow::Config::XML - Parse workflow configurations from XML content
 
+=head1 VERSION
+
+This documentation describes version 1.05 of this package
+
 =head1 SYNOPSIS
 
  my $parser = Workflow::Config->new( 'xml' );
