@@ -1,28 +1,30 @@
 package Workflow::Exception;
 
-# $Id: Exception.pm,v 1.8 2006/07/08 20:02:33 jonasbn Exp $
+# $Id: Exception.pm 539 2012-10-25 16:19:14Z jonasbn $
 
+use warnings;
 use strict;
 
 # Declare some of our exceptions...
 
 use Exception::Class (
-   'Workflow::Exception::Condition' => {
-      isa         => 'Workflow::Exception',
-      description => 'Condition failed errors',
-   },
-   'Workflow::Exception::Configuration' => {
-      isa         => 'Workflow::Exception',
-      description => 'Configuration errors',
-   },
-   'Workflow::Exception::Persist' => {
-      isa         => 'Workflow::Exception',
-      description => 'Persistence errors',
-   },
-   'Workflow::Exception::Validation' => {
-      isa         => 'Workflow::Exception',
-      description => 'Validation errors',
-   },
+    'Workflow::Exception::Condition' => {
+        isa         => 'Workflow::Exception',
+        description => 'Condition failed errors',
+    },
+    'Workflow::Exception::Configuration' => {
+        isa         => 'Workflow::Exception',
+        description => 'Configuration errors',
+    },
+    'Workflow::Exception::Persist' => {
+        isa         => 'Workflow::Exception',
+        description => 'Persistence errors',
+    },
+    'Workflow::Exception::Validation' => {
+        isa         => 'Workflow::Exception',
+        description => 'Validation errors',
+        fields      => 'invalid_fields',
+    },
 );
 
 use Log::Log4perl qw( get_logger );
@@ -35,26 +37,32 @@ my %TYPE_CLASSES = (
     workflow_error      => 'Workflow::Exception',
 );
 
-$Workflow::Exception::VERSION   = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+$Workflow::Exception::VERSION   = '1.09';
 @Workflow::Exception::ISA       = qw( Exporter Exception::Class::Base );
 @Workflow::Exception::EXPORT_OK = keys %TYPE_CLASSES;
 
 # Exported shortcuts
 
 sub _mythrow {
-    my $type = shift @_;
-    my ( $msg, %params ) = _massage( @_ );
+    my ( $type, @items ) = @_;
+
+    my ( $msg, %params ) = _massage(@items);
     my $log = get_logger();
-    my ( $pkg, $line ) = (caller)[0,2];
-    my ( $prev_pkg, $prev_line ) = (caller(1))[0,2];
+    my ( $pkg, $line ) = (caller)[ 0, 2 ];
+    my ( $prev_pkg, $prev_line ) = ( caller 1 )[ 0, 2 ];
     $log->error( "$type exception thrown from [$pkg: $line; before: ",
-                 "$prev_pkg: $prev_line]: $msg" );
-    goto &Exception::Class::Base::throw( $TYPE_CLASSES{ $type },
-                                         message => $msg, %params );
+        "$prev_pkg: $prev_line]: $msg" );
+    goto &Exception::Class::Base::throw(
+        $TYPE_CLASSES{$type},
+        message => $msg,
+        %params
+    );
 }
 
 # Use 'goto' here to maintain the stack trace
 
+## no critic (Subroutines::RequireArgUnpacking)
+
 sub condition_error {
     unshift @_, 'condition_error';
     goto &_mythrow;
@@ -84,16 +92,17 @@ sub workflow_error {
 # the right format for E::C
 
 sub throw {
-    my $class = shift @_;
-    my ( $msg, %params ) = _massage( @_ );
+    my ( $class, @items ) = @_;
+
+    my ( $msg, %params ) = _massage(@items);
     goto &Exception::Class::Base::throw( $class, message => $msg, %params );
 }
 
 sub _massage {
     my @items = @_;
-    my %params = ( ref $items[-1] eq 'HASH' )
-                   ? %{ pop( @items ) } : ();
-    my $msg    = join( '', @items );
+
+    my %params = ( ref $items[-1] eq 'HASH' ) ? %{ pop @items } : ();
+    my $msg = join '', @items;
     return ( $msg, %params );
 }
 
@@ -105,6 +114,10 @@ __END__
 
 Workflow::Exception - Base class for workflow exceptions
 
+=head1 VERSION
+
+This documentation describes version 1.08 of this package
+
 =head1 SYNOPSIS
 
  # Standard usage
@@ -164,15 +177,35 @@ makes for very readable code:
                 "frightfully wrong: $@",
                 { foo => 'bar' };
 
-#=head3 condition_error
+=head3 condition_error
 
-#=head3 configuration_error
+This method transforms the error to a condition error.
 
-#=head3 persist_error
+This exception is thrown via </mythrow> when a condition of a workflow is invalid.
 
-#=head3 validation_error
+=head3 configuration_error
 
-#=head3 workflow_error
+This method transforms the error to a configuration error.
+
+This exception is thrown via </mythrow> when configuration of a workflow is unsuccessful.
+
+=head3 persist_error
+
+This method transforms the error to a persistance error.
+
+This exception is thrown via </mythrow> when the save of a workflow is unsuccessful.
+
+=head3 validation_error
+
+This method transforms the error to a validation error.
+
+This exception is thrown via </mythrow> when input data or similar of a workflow is unsuccessful.
+
+=head3 workflow_error
+
+This method transforms the error to a workflow error.
+
+This exception is thrown via </mythrow> when input data or similar of a workflow is unsuccessful.
 
 =head1 SHORTCUTS
 
@@ -192,11 +225,15 @@ L<Exception::Class|Exception::Class>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2004 Chris Winters. All rights reserved.
+Copyright (c) 2003-2010 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
+Jonas B. Nielsen (jonasbn) E<lt>jonasbn@cpan.orgE<gt> is the current maintainer.
+
+Chris Winters E<lt>chris@cwinters.comE<gt>, original author.
+
+=cut
