@@ -1,56 +1,55 @@
 package Workflow::Persister::SPOPS;
 
-# $Id: SPOPS.pm 316 2007-07-04 19:17:50Z jonasbn $
+# $Id: SPOPS.pm 539 2012-10-25 16:19:14Z jonasbn $
 
+use warnings;
 use strict;
 use base qw( Workflow::Persister );
 use DateTime;
-use Log::Log4perl       qw( get_logger );
+use Log::Log4perl qw( get_logger );
 use Workflow::Exception qw( configuration_error persist_error );
+use English qw( -no_match_vars );
 
 $Workflow::Persister::SPOPS::VERSION = '1.07';
 
 my @FIELDS = qw( workflow_class history_class );
-__PACKAGE__->mk_accessors( @FIELDS );
+__PACKAGE__->mk_accessors(@FIELDS);
 
 sub init {
     my ( $self, $params ) = @_;
-    $self->SUPER::init( $params );
+    $self->SUPER::init($params);
     unless ( $params->{workflow_class} ) {
         configuration_error "SPOPS implementation for persistence must ",
-                            "specify 'workflow_class' parameter ",
-                            "in configuration.";
+            "specify 'workflow_class' parameter ", "in configuration.";
     }
     $self->workflow_class( $params->{workflow_class} );
     unless ( $params->{history_class} ) {
         configuration_error "SPOPS implementation for persistence must ",
-                            "specify 'history_class' parameter ",
-                            "in configuration."
+            "specify 'history_class' parameter ", "in configuration.";
     }
     $self->history_class( $params->{history_class} );
 }
 
 sub create_workflow {
     my ( $self, $wf ) = @_;
-    my $wf_persist = $self->workflow_class->new({
-        state       => $wf->state,
-        type        => $wf->type,
-        last_update => DateTime->now,
-    });
+    my $wf_persist = $self->workflow_class->new(
+        {   state       => $wf->state,
+            type        => $wf->type,
+            last_update => DateTime->now( time_zone => $wf->time_zone() ),
+        }
+    );
     eval { $wf_persist->save };
-    if ( $@ ) {
-        persist_error "Failed to create new workflow: $@";
+    if ($EVAL_ERROR) {
+        persist_error "Failed to create new workflow: $EVAL_ERROR";
     }
     return $wf_persist->id;
 }
 
 sub fetch_workflow {
     my ( $self, $wf_id ) = @_;
-    my $wf_persist = eval {
-        $self->workflow_class->fetch( $wf_id )
-    };
-    if ( $@ ) {
-        persist_error "Failed to fetch workflow '$wf_id': $@";
+    my $wf_persist = eval { $self->workflow_class->fetch($wf_id) };
+    if ($EVAL_ERROR) {
+        persist_error "Failed to fetch workflow '$wf_id': $EVAL_ERROR";
     }
     return $wf_persist;
 }
@@ -58,15 +57,16 @@ sub fetch_workflow {
 sub update_workflow {
     my ( $self, $wf ) = @_;
     my $wf_id = $wf->id;
-    my $wf_persist = eval { $self->workflow_class->fetch( $wf_id ) };
-    if ( $@ ) {
-        persist_error "Cannot fetch record '$wf_id' for updating: $@";
+    my $wf_persist = eval { $self->workflow_class->fetch($wf_id) };
+    if ($EVAL_ERROR) {
+        persist_error
+            "Cannot fetch record '$wf_id' for updating: $EVAL_ERROR";
     }
     $wf_persist->state( $wf->state );
     $wf_persist->last_update( $wf->last_update );
     eval { $wf_persist->save };
-    if ( $@ ) {
-        persist_error "Failed to update workflow '$wf_id': $@";
+    if ($EVAL_ERROR) {
+        persist_error "Failed to update workflow '$wf_id': $EVAL_ERROR";
     }
     return $wf_persist;
 }
@@ -75,25 +75,26 @@ sub create_history {
     my ( $self, $wf, @history ) = @_;
     my $log = get_logger();
     $log->debug( "Saving history for workflow ", $wf->id );
-    foreach my $h ( @history ) {
+    foreach my $h (@history) {
         next if ( $h->is_saved );
         my $hist_persist = eval {
-            $self->history_class->new({
-                workflow_id  => $wf->id,
-                action       => $h->action,
-                description  => $h->description,
-                state        => $h->state,
-                user         => $h->user,
-                history_date => $h->date
-            })->save();
+            $self->history_class->new(
+                {   workflow_id  => $wf->id,
+                    action       => $h->action,
+                    description  => $h->description,
+                    state        => $h->state,
+                    user         => $h->user,
+                    history_date => $h->date
+                }
+            )->save();
         };
-        if ( $@ ) {
-            persist_error "Failed to save history record: $@";
-        }
-        else {
+        if ($EVAL_ERROR) {
+            persist_error "Failed to save history record: $EVAL_ERROR";
+        } else {
             $h->id( $hist_persist->id );
             $h->set_saved();
-            $log->info( "Created history record with ID ", $hist_persist->id );
+            $log->info( "Created history record with ID ",
+                $hist_persist->id );
         }
     }
     return @history;
@@ -102,25 +103,31 @@ sub create_history {
 sub fetch_history {
     my ( $self, $wf ) = @_;
     my $persist_histories = eval {
-        $self->history_class->fetch_group({ where => 'workflow_id = ?',
-                                            value => [ $wf->id ],
-                                            order => 'history_date DESC' });
+        $self->history_class->fetch_group(
+            {   where => 'workflow_id = ?',
+                value => [ $wf->id ],
+                order => 'history_date DESC'
+            }
+        );
     };
-    if ( $@ ) {
-        persist_error "Error fetching workflow history: $@";
+    if ($EVAL_ERROR) {
+        persist_error "Error fetching workflow history: $EVAL_ERROR";
     }
     my @histories = ();
-    for ( @{ $persist_histories } ) {
-        my $hist = Workflow::History->new({
-            id           => $_->id,
-            workflow_id  => $_->workflow_id,
-            action       => $_->action,
-            description  => $_->description,
-            state        => $_->state,
-            user         => $_->user,
-# NOTE: SPOPS class must return this as a DateTime object...
-            date         => $_->history_date,
-        });
+    for ( @{$persist_histories} ) {
+        my $hist = Workflow::History->new(
+            {   id          => $_->id,
+                workflow_id => $_->workflow_id,
+                action      => $_->action,
+                description => $_->description,
+                state       => $_->state,
+                user        => $_->user,
+
+                # NOTE: SPOPS class must return this as a DateTime object...
+                date      => $_->history_date,
+                time_zone => $_->time_zone,
+            }
+        );
         $hist->set_saved();
         push @histories, $hist;
     }
@@ -135,6 +142,10 @@ __END__
 
 Workflow::Persister::SPOPS - Persist workflows using SPOPS
 
+=head1 VERSION
+
+This documentation describes version 1.07 of this package
+
 =head1 SYNOPSIS
 
  <persister name="SPOPSPersister"
