@@ -1,15 +1,16 @@
 package Workflow::Persister::UUID;
 
-# $Id: UUID.pm,v 1.3 2006/07/08 20:02:33 jonasbn Exp $
+# $Id: UUID.pm 539 2012-10-25 16:19:14Z jonasbn $
 
+use warnings;
 use strict;
 use Data::UUID;
 
-$Workflow::Persister::UUID::VERSION  = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
+$Workflow::Persister::UUID::VERSION = '1.03';
 
 sub new {
     my ( $class, $params ) = @_;
-    my $self = bless( { gen => Data::UUID->new() }, $class );
+    my $self = bless { gen => Data::UUID->new() }, $class;
     return $self;
 }
 
@@ -18,7 +19,7 @@ sub pre_fetch_id {
     return $self->{gen}->create_str();
 }
 
-sub post_fetch_id { return }
+sub post_fetch_id {return}
 
 1;
 
@@ -28,6 +29,10 @@ __END__
 
 Workflow::Persister::UUID - Persister to generate Universally Unique Identifiers
 
+=head1 VERSION
+
+This documentation describes version 1.03 of this package
+
 =head1 SYNOPSIS
 
  <persister
@@ -47,11 +52,35 @@ look there if you are curious about the algorithm, efficiency, etc.
 
 =head2 METHODS
 
-#=head3 new
+=head3 new
 
-#=head3 pre_fetch_id
+Instantiates a Workflow::Persister::UUID object, which is actually an
+encapsulation of L<Data::UUID>.
 
-#=head3 post_fetch_id
+=head3 pre_fetch_id
+
+L</pre_fetch_id> can then be used to generate/retrieve a unique ID, generated
+by L<Data::UUID>.
+
+=head3 post_fetch_id
+
+This method is unimplemented at this time, please see the TODO.
+
+=head1 TODO
+
+=over
+
+=item * Implement L</post_fetch_id>
+
+=back 
+
+=head1 SEE ALSO
+
+=over
+
+=item L<Data::UUID>
+
+=back
 
 =head1 COPYRIGHT
 
